@@ -9,12 +9,17 @@ CLIENT_ID = None
 CLIENT_SECRET = None
 BASE_URL = None
 
-PUT_USER_CALLBACK = None
+def _notset_put_user_callback(*args, **kwargs):
+    raise RuntimeError('You have not set "put_user_callback" yet')
+
+PUT_USER_CALLBACK = _notset_put_user_callback
+
 
 def set_put_user_callback(fn):
     global PUT_USER_CALLBACK
     PUT_USER_CALLBACK = fn
 
+
 def signin_url(request, _cont=None, _query={}, **kwargs):
     if _cont:
         _query['_cont'] = _cont
@@ -23,6 +28,7 @@ def signin_url(request, _cont=None, _query={}, **kwargs):
                              _query=_query,
                              **kwargs)
 
+
 def signout_url(request, _cont=None, _query={}, **kwargs):
     if _cont:
         _query['_cont'] = _cont
@@ -57,11 +63,12 @@ def includeme(config):
     CLIENT_ID = get_config('client_id')
     CLIENT_SECRET = get_config('client_secret')
 
-    put_user_callback_path = get_config('put_user_callback')
-    module_name, attr_name = put_user_callback_path.rsplit('.', 1)
-    module = importlib.import_module(module_name, package=None)
-    put_user_callback_fn = getattr(module, attr_name)
-    set_put_user_callback(put_user_callback_fn)
+    put_user_callback_path = conf.get('put_user_callback', None)
+    if put_user_callback_path:
+        module_name, attr_name = put_user_callback_path.rsplit('.', 1)
+        module = importlib.import_module(module_name, package=None)
+        put_user_callback_fn = getattr(module, attr_name)
+        set_put_user_callback(put_user_callback_fn)
 
     BASE_URL = get_config('base_url').lstrip('/') + '/'
     config.add_route('pyramid_vgid_oauth2', BASE_URL + '*traverse')
