@@ -1,8 +1,9 @@
+import six
 from pyramid.view import view_config
 from pyramid.httpexceptions import HTTPFound, HTTPBadRequest
 from pyramid.url import urlencode
 from pyramid.security import remember, forget
-import events
+from . import events
 from pyramid.events import subscriber
 from pyramid_vgid_oauth2.models import AccessCode
 import pyramid_vgid_oauth2 as pvo
@@ -22,10 +23,10 @@ def signin(request):
 @view_config(route_name='pyramid_vgid_oauth2', name='callback')
 def callback(request):
     if 'access_code' not in request.params:
-        raise HTTPBadRequest('access_code argument is missing')
+        raise HTTPBadRequest(u'access_code argument is missing')
     access_code = AccessCode(request.params['access_code'])
     if not access_code.verify():
-        return HTTPBadRequest('Can not request AccessToken from AccessCode#%s' % access_code)
+        return HTTPBadRequest(six.text_type('Can not request AccessToken from AccessCode#%s' % access_code))
 
     user = access_code.user
     request.registry.notify(events.SignIn(request, access_code))
